@@ -2,10 +2,10 @@ from fastmcp import FastMCP
 from scripts.sirene import search_sirene_company
 import os
 import pynsee
+from pynsee import init_conn
 
 def run():
     app = FastMCP("insee-server")
-    pynsee.init_conn(sirene_key=os.getenv("API_KEY"))
     @app.tool()
     async def search_company(
         company_name: str = None,
@@ -28,7 +28,8 @@ def run():
         return search_sirene_company(company_name, siren, siret, fuzzy)
 
     # Lancement du serveur avec transport streamable-http
-    app.run(transport="streamable-http", host="127.0.0.1", port=8000, path="/mcp")
+    app.run(transport="streamable-http", host="127.0.0.1", port=9000, path="/mcp")
 
 if __name__ == "__main__":
+    init_conn(sirene_key=os.environ["API_KEY"])
     run()
